**************************************************************************************
* General Sep-up
**************************************************************************************

clear all
set more off


*import the data and set up:

import excel "Monetary-Incentive Competition between Humans and Robots_ Experiment Data.xlsx", cellrange(:R673) firstrow clear

foreach var of varlist * {
  rename `var' `=strlower("`var'")'
}

drop if id==.

save "robot_data.dta", replace

global data  "robot_data"


use $data, clear

*drop the with data recording problem
drop if id==26
 
log using replication_robot.log, replace


************************************************************************************
* Table I
************************************************************************************
table round, c(N robot mean robot sd robot mean human sd human) 
table round, c(N robot min robot min human max robot max human)
table round, c(N incorrectattempts min incorrectattempts max incorrectattempts mean incorrectattempts sd incorrectattempts)

sum human robot prize money_belief competitivness self_efficacy rob_like rob_competent per_competent if round>0

************************************************************************************
* Table II
************************************************************************************
 
xtset id round
xtreg human robot prize c.robot#c.prize i.round if round>0, i(id) fe
*test for joint significance:
test robot prize c.robot#c.prize
test robot c.robot#c.prize
test prize c.robot#c.prize

************************************************************************************
* Table III
************************************************************************************
xtreg human prize robot i.round if round>0, i(id) fe



************************************************************************************
* Table IV
************************************************************************************
xtreg rob_competent prize robot i.round if round>0, i(id) fe


************************************************************************************
* Table V
************************************************************************************
xtreg rob_like prize robot i.round if round>0, i(id) fe


************************************************************************************
* Table VI
************************************************************************************
xtreg per_competent prize robot i.round if round>0, i(id) fe



************************************************************************************
* Generate centered variables:
************************************************************************************
qui{
 local vars "prize money_belief robot competitivness"

foreach var of local vars {
sum `var' if round>0
local mean= round(r(mean), 0.0001)
generate c_`var'=`var'-`mean'
}

* Means for the relevant 599 observations:
sum self_efficacy if round>0 & rob_like!=.
local mean= round(r(mean), 0.0001)
generate c_self_efficacy=self_efficacy-`mean'

sum robot if round>0 & rob_like!=.
local mean= round(r(mean), 0.0001)
generate c1_robot=robot-`mean'
}
************************************************************************************
* Table VII
************************************************************************************

reg human c_prize robot c_money_belief c.c_prize#c.c_money_belief i.round if round>0


************************************************************************************
* Table VIII
************************************************************************************
reg per_competent prize c.c_self_efficacy##c.c1_robot i.round if round>0
*reg per_competent c.self_efficacy##c.robot i.round  
*margins, dydx(self_efficacy) at(robot=(`meanrobot'))
*margins, dydx(robot) at(self_efficacy=(`meanself_efficacy'))

************************************************************************************
* Table IX
************************************************************************************

reg human prize c.c_competitivness##c.c_robot i.round if round>0
*reg human c.competitivness##c.robot i.round
*margins, dydx(competitivness) at(robot=(`meanrobot'))
*margins, dydx(robot) at(competitivness=(`meancompetitivness'))

************************************************************************************
* Table X
************************************************************************************

xtreg incorrectattempts prize robot i.round if round>0, i(id) fe

*Other reported results (not in tables):
	*in "other anecdoatl results:"
reg human prize robot self_efficacy i.round if round>0
 *in dicussion (table VI including human score):
xtreg per_competent human prize robot i.round if round>0, i(id) fe



log close


